@@ -1,4 +1,4 @@
-#' @title tooltip settings
+#' @title Tooltip settings
 #' @description Settings to be used with \code{\link{girafe}}
 #' for tooltip customisation.
 #' @param css extra css (added to \code{position: absolute;pointer-events: none;})
@@ -36,15 +36,22 @@
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-#' @seealso set options with \code{\link{girafe_options}}
-opts_tooltip <- function(
-  css = NULL, offx = 10, offy = 0, use_cursor_pos = TRUE,
-  opacity = .9, use_fill = FALSE, use_stroke = FALSE,
-  delay_mouseover = 200, delay_mouseout = 500, zindex = 999){
-
-  if( is.null(css)){
-    css <- "padding:5px;background:black;color:white;border-radius:2px 2px 2px 2px;"
-  }
+opts_tooltip <- function(css = NULL,
+                         offx = 10,
+                         offy = 0,
+                         use_cursor_pos = TRUE,
+                         opacity = .9,
+                         use_fill = FALSE,
+                         use_stroke = FALSE,
+                         delay_mouseover = 200,
+                         delay_mouseout = 500,
+                         zindex = 999) {
+  css <- check_css(
+    css = css,
+    default = "padding:5px;background:black;color:white;border-radius:2px 2px 2px 2px",
+    cls_prefix = "tooltip_",
+    name = "opts_tooltip"
+  )
   if( grepl(x = css, pattern = "position[ ]*:") )
     stop("do not specify position in css, this parameter is managed by girafe.")
   if( grepl(x = css, pattern = "pointer-events[ ]*:") )
@@ -59,9 +66,13 @@ opts_tooltip <- function(
   stopifnot(zindex >= 1)
   zindex <- round(zindex, digits = 0)
 
-  css <- paste0("{position:absolute;pointer-events:none;",
-                sprintf("z-index:%.0f;", zindex),
-                css, "}")
+  css <- sub("\\}\n$",
+             paste0(
+               "; position:absolute;pointer-events:none;",
+               sprintf("z-index:%.0f;", zindex),
+               "}\n"
+             ),
+             css)
   x <- list(
     css = css,
     offx = offx, offy = offy,
@@ -75,11 +86,15 @@ opts_tooltip <- function(
   x
 }
 
-#' @title hover effect settings
-#' @description Allows customization of the animation
-#' of graphic elements on which the mouse is positioned.
-#' @param css css to associate with elements to be animated
-#' when mouse is hover them.
+#' @title Hover effect settings
+#' @description Allows customization of the rendering
+#' of graphic elements when the user hovers over them with the cursor (mouse pointer).
+#' Use \code{opts_hover} for interactive geometries in panels,
+#' \code{opts_hover_key} for interactive scales/guides and
+#' \code{opts_hover_theme} for interactive theme elements.
+#' @param css css to associate with elements when they are hovered.
+#' It must be a scalar character. It can also be constructed with
+#' \code{\link{girafe_css}}, to give more control over the css for different element types.
 #' @examples
 #' library(ggplot2)
 #'
@@ -98,27 +113,51 @@ opts_tooltip <- function(
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-#' @seealso set options with \code{\link{girafe_options}}
-opts_hover <- function(css = NULL){
-
-  if( is.null(css)){
-    css <- "fill:orange;stroke:gray;"
-  }
-  css <- paste0("{", css, "}")
-  x <- list(
-    css = css
-  )
-  class(x) <- "opts_hover"
-  x
+opts_hover <- function(css = NULL) {
+  css <- check_css(css,
+                   default = "fill:orange;stroke:gray;",
+                   cls_prefix = "hover_",
+                   name = "opts_hover")
+  structure(list(css = css),
+            class = "opts_hover")
 }
 
-#' @title selection effect settings
+#' @export
+#' @rdname opts_hover
+opts_hover_key <- function(css = NULL) {
+  css <- check_css(css,
+                   default = "stroke:red;",
+                   cls_prefix = "hover_key_",
+                   name = "opts_hover")
+  structure(list(css = css),
+            class = "opts_hover_key")
+}
+
+#' @export
+#' @rdname opts_hover
+opts_hover_theme <- function(css = NULL) {
+  css <- check_css(css,
+                   default = "fill:green;",
+                   cls_prefix = "hover_theme_",
+                   name = "opts_hover_theme")
+  structure(list(css = css),
+            class = "opts_hover_theme")
+}
+
+#' @title Selection effect settings
 #' @description Allows customization of the rendering of
 #' selected graphic elements.
+#' Use \code{opts_selection} for interactive geometries in panels,
+#' \code{opts_selection_key} for interactive scales/guides and
+#' \code{opts_selection_theme} for interactive theme elements.
 #' @param css css to associate with elements when they are selected.
+#' It must be a scalar character. It can also be constructed with
+#' \code{\link{girafe_css}}, to give more control over the css for different element types.
 #' @param type selection mode ("single", "multiple", "none")
 #'  when widget is in a Shiny application.
 #' @param only_shiny disable selections if not in a shiny context.
+#' @param selected character vector, id to be selected when the graph will be
+#' initialized.
 #' @examples
 #' library(ggplot2)
 #'
@@ -138,27 +177,68 @@ opts_hover <- function(css = NULL){
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-#' @seealso set options with \code{\link{girafe_options}}
-opts_selection <- function(css = NULL, type = "multiple", only_shiny = TRUE){
-
-  if( is.null(css)){
-    css <- "fill:red;stroke:gray;"
-  }
-
+opts_selection <- function(css = NULL,
+                           type = "multiple",
+                           only_shiny = TRUE,
+                           selected = character(0)) {
+  css <- check_css(css,
+                   default = "fill:red;stroke:gray;",
+                   cls_prefix = "selected_",
+                   name = "opts_selection")
   stopifnot(type %in%
               c("single", "multiple", "none"))
-
-  css <- paste0("{", css, "}")
-  x <- list(
+  structure(list(
     css = css,
     type = type,
-    only_shiny = only_shiny
-  )
-  class(x) <- "opts_selection"
-  x
+    only_shiny = only_shiny,
+    selected = selected
+  ),
+  class = "opts_selection")
 }
 
-#' @title zoom settings
+#' @export
+#' @rdname opts_selection
+opts_selection_key <- function(css = NULL,
+                               type = "single",
+                               only_shiny = TRUE,
+                               selected = character(0)) {
+  css <- check_css(css,
+                   default = "stroke:gray;",
+                   cls_prefix = "selected_key_",
+                   name = "opts_selection_key")
+  stopifnot(type %in%
+              c("single", "multiple", "none"))
+  structure(list(
+    css = css,
+    type = type,
+    only_shiny = only_shiny,
+    selected = selected
+  ),
+  class = "opts_selection_key")
+}
+
+#' @export
+#' @rdname opts_selection
+opts_selection_theme <- function(css = NULL,
+                                 type = "single",
+                                 only_shiny = TRUE,
+                                 selected = character(0)) {
+  css <- check_css(css,
+                   default = "stroke:gray;",
+                   cls_prefix = "selected_theme_",
+                   name = "opts_selection_theme")
+  stopifnot(type %in%
+              c("single", "multiple", "none"))
+  structure(list(
+    css = css,
+    type = type,
+    only_shiny = only_shiny,
+    selected = selected
+  ),
+  class = "opts_selection_theme")
+}
+
+#' @title Zoom settings
 #' @description Allows customization of the zoom.
 #' @param min minimum zoom factor
 #' @param max maximum zoom factor
@@ -180,7 +260,6 @@ opts_selection <- function(css = NULL, type = "multiple", only_shiny = TRUE){
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-#' @seealso set options with \code{\link{girafe_options}}
 opts_zoom <- function(min = 1, max = 1){
 
   stopifnot(is.numeric(min), is.numeric(max))
@@ -198,7 +277,7 @@ opts_zoom <- function(min = 1, max = 1){
   x
 }
 
-#' @title toolbar settings
+#' @title Toolbar settings
 #' @description Allows customization of the toolbar
 #' @param position one of 'top', 'bottom', 'topleft', 'topright', 'bottomleft', 'bottomright'
 #' @param saveaspng set to TRUE to propose the 'save as png' button.
@@ -224,7 +303,6 @@ opts_zoom <- function(min = 1, max = 1){
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-#' @seealso set options with \code{\link{girafe_options}}
 opts_toolbar <- function(position = "topright", saveaspng = TRUE){
 
   stopifnot(position %in% c("top", "bottom",
@@ -240,13 +318,12 @@ opts_toolbar <- function(position = "topright", saveaspng = TRUE){
 }
 
 
-#' @title girafe sizing settings
+#' @title Girafe sizing settings
 #' @description Allows customization of the svg style sizing
 #' @param rescale if FALSE, graphic will not be resized
 #' and the dimensions are exactly those of the container.
 #' @param width widget width ratio (0 < width <= 1).
-#' @family girafe sizing options
-#' @seealso set options with \code{\link{girafe_options}}
+#' @family girafe animation options
 #' @examples
 #' library(ggplot2)
 #'
@@ -279,7 +356,7 @@ opts_sizing <- function(rescale = TRUE, width = 1){
   x
 }
 
-#' @title set girafe options
+#' @title Set girafe options
 #' @description Defines the animation options related to
 #' a \code{\link{girafe}} object.
 #' @param x girafe object.
@@ -309,27 +386,16 @@ opts_sizing <- function(rescale = TRUE, width = 1){
 #'   print(x)
 #' }
 #' @export
-#' @seealso \code{\link{opts_tooltip}}, \code{\link{opts_hover}},
-#' \code{\link{opts_selection}}, \code{\link{opts_zoom}}, \code{\link{opts_sizing}},
-#' \code{\link{opts_toolbar}}, \code{\link[htmlwidgets]{sizingPolicy}}
+#' @seealso \code{\link{girafe}}
+#' @family girafe animation options
 girafe_options <- function(x, ...){
   stopifnot(inherits(x, "girafe"))
 
   args <- list(...)
+  x$x$settings <- merge_options(x$x$settings, args)
+
   for (arg in args) {
-    if (inherits(arg, "opts_zoom")) {
-      x$x$settings$zoom <- arg
-    } else if (inherits(arg, "opts_selection")) {
-      x$x$settings$capture <- arg
-    } else if (inherits(arg, "opts_tooltip")) {
-      x$x$settings$tooltip <- arg
-    } else if (inherits(arg, "opts_hover")) {
-      x$x$settings$hover <- arg
-    } else if (inherits(arg, "opts_toolbar")) {
-      x$x$settings$toolbar <- arg
-    } else if (inherits(arg, "opts_sizing")) {
-      x$x$settings$sizing <- arg
-    } else if (all(names(arg) %in% c("defaultWidth", "defaultHeight", "padding", "viewer", "browser", "knitr"))) {
+    if (all(names(arg) %in% c("defaultWidth", "defaultHeight", "padding", "viewer", "browser", "knitr"))) {
       x$sizingPolicy <- arg
     }
   }
