@@ -3,11 +3,11 @@ shinyUI(fluidPage(
   sidebarLayout(
 
     sidebarPanel(
-      textInput("selpoint", label = "Selected point")
+      uiOutput("selpoint")
     ),
 
     mainPanel(
       girafeOutput("plot")
     )
   )
-))
\ No newline at end of file
+))
